.. Copyright (C) 2014-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2019      Alin Alexandru <alin.alexandru@innobyte.com>
.. Copyright (C) 2015-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

`phpIPAM`_  is an open-source web IP address management application (IPAM).
Its goal is to provide light, modern and useful IP address management.
It is php-based application with MySQL database backend, using jQuery
libraries, ajax and HTML5/CSS3 features.

The ``debops.phpipam`` role installs this ipam on a specified host with
nginx as a webserver (using :ref:`debops.nginx`).

.. _phpIPAM: https://phpipam.net/
